Removes the boxtracker file, adds to .blfsignore, and optionally removes it from .gitignore so that git will start tracking it again.
Examples
#create temp dir to modify files cleanly
tmp <- blfs:::create_test_repo(box_lfs=TRUE, examples = TRUE,
source_dir = system.file("extdata", package = "blfs"))
rm_tracking(tmp, "example-files/large-file1.txt")
#> ✔ example-files/large-file1.txt has been successfully untracked with Box-LFS
rm_tracking(tmp, "example-files/example-shp.shp", git=FALSE)
#> ! example-files/example-shp will no longer be tracked by Git or Box-LFS
#> ✔ example-files/example-shp has been successfully untracked with Box-LFS
#remove temp dirs
unlink(tmp, recursive = TRUE)